[![DeepSource](https://deepsource.io/gh/hikariatama/acunetix.svg/?label=active+issues&show_trend=true&token=IPVI_QX-cSuQSVeVl8cb5PLt)](https://deepsource.io/gh/hikariatama/acunetix/?ref=repository-badge)  

[![DeepSource](https://deepsource.io/gh/hikariatama/acunetix.svg/?label=resolved+issues&show_trend=true&token=IPVI_QX-cSuQSVeVl8cb5PLt)](https://deepsource.io/gh/hikariatama/acunetix/?ref=repository-badge)  

![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/hikariatama/acunetix)
![GitHub repo size](https://img.shields.io/github/repo-size/hikariatama/acunetix)
![License](https://img.shields.io/github/license/hikariatama/acunetix)
![Forks](https://img.shields.io/github/forks/hikariatama/acunetix?style=flat)
![Stars](https://img.shields.io/github/stars/hikariatama/acunetix?style=flat)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
# Bear with us while we're getting this sorted out...
